@@ -4,6 +4,7 @@
 from pathlib import Path
 import numpy as np
 import pandas as pd
+import datetime
 from covsirphy.util.error import SubsetNotFoundError
 from covsirphy.cleaning.cbase import CleaningBase
 
@@ -112,6 +113,22 @@ class VaccineData(CleaningBase):
         for col in [self.VAC, self.V_ONCE, self.V_FULL]:
             df[col] = pd.to_numeric(df[col], errors="coerce")
             df[col] = df.groupby(self.ISO3)[col].fillna(method="ffill").fillna(0).astype(np.int64)
+        today_date = datetime.datetime.today().replace(hour=00, minute=00, second=00, microsecond=00)
+        for country in df.Country.unique():
+            subset_df = df.loc[df[self.COUNTRY] == country]
+            # Add any missing dates up until today
+            if subset_df[self.DATE].max() < today_date:
+                new_dates = pd.date_range(
+                    subset_df[self.DATE].max() + datetime.timedelta(days=1), today_date)
+                subset_df = subset_df.reset_index(drop=True)
+                keep_index = subset_df[self.VAC].idxmax() + 1
+                new_df = pd.DataFrame(index=new_dates, columns=subset_df.columns)
+                new_df.index.name = self.DATE
+                new_df = new_df.drop(self.DATE, axis=1).reset_index()
+                subset_df = pd.concat([subset_df, new_df], axis=0, ignore_index=True).ffill()
+                subset_df = subset_df.loc[keep_index:]
+                df = pd.concat([df, subset_df], axis=0, ignore_index=True)
+        df.sort_values(by=[self.COUNTRY, self.DATE], ignore_index=True, inplace=True)
         return df.loc[:, self.VAC_COLS]
 
     def subset(self, country, product=None, start_date=None, end_date=None):
@@ -143,10 +160,10 @@ class VaccineData(CleaningBase):
             df = df.loc[df[self.PRODUCT] == product]
         # Subset with start date
         if start_date is not None:
-            df = df.loc[df[self.DATE] >= self.date_obj(start_date)]
+            df = df.loc[df[self.DATE] >= self._ensure_date(start_date)]
         # Subset with end date
         if end_date is not None:
-            df = df.loc[df[self.DATE] <= self.date_obj(end_date)]
+            df = df.loc[df[self.DATE] <= self._ensure_date(end_date)]
         # Check records were found
         if df.empty:
             raise SubsetNotFoundError(
