@@ -2,6 +2,8 @@
 # -*- coding: utf-8 -*-
 
 from datetime import timedelta
+from math import log10, floor
+import numpy as np
 import pandas as pd
 from sklearn.model_selection import train_test_split
 from covsirphy.util.argument import find_args
@@ -56,7 +58,7 @@ class _RegressorBase(Term):
             X (pandas.DataFrame): indicators with time index
             y (pandas.DataFrame): target values with time index
             delay (int): delay period [days]
-            kwargs: keyword arguments of sklearn.model_selection.train_test_split(test_size=0.2, random_state=0)
+            kwargs: keyword arguments of sklearn.model_selection.train_test_split()
 
         Returns:
             tuple(pandas.DataFrame): datasets with time index
@@ -68,8 +70,12 @@ class _RegressorBase(Term):
 
         Note:
             If @seed is included in kwargs, this will be converted to @random_state.
+
+        Note:
+            default values regarding sklearn.model_selection.train_test_split() are
+            test_size=0.2, random_state=0, shuffle=False.
         """
-        split_kwargs = {"test_size": 0.2, "random_state": 0, }
+        split_kwargs = {"test_size": 0.2, "random_state": 0, "shuffle": False}
         split_kwargs.update(kwargs)
         split_kwargs["random_state"] = split_kwargs.get("seed", split_kwargs["random_state"])
         split_kwargs = find_args(train_test_split, **split_kwargs)
@@ -143,13 +149,16 @@ class _RegressorBase(Term):
     def predict(self):
         """
         Predict parameter values (via y) with self._regressor and X_target.
-        This method should be overwritten by child classes.
 
         Returns:
             pandas.DataFrame:
                 Index
                     Date (pandas.Timestamp): future dates
                 Columns
-                    (float): parameter values
+                    (float): parameter values (4 digits)
         """
-        raise NotImplementedError
+        # Predict parameter values
+        predicted = self._regressor.predict(self._X_target)
+        df = pd.DataFrame(predicted, index=self._X_target.index, columns=self._y_train.columns)
+        # parameter values: 4 digits
+        return df.applymap(lambda x: np.around(x, 4 - int(floor(log10(abs(x)))) - 1))
